Avena is an image processing library and command-line tool.

|image0| |image1| |image2| |image3| |image4|

Install Avena
-------------

Avena requires:

-  `Python <https://www.python.org/>`__ (version 2 or 3);
-  the `Python Imaging
   Library <http://pythonware.com/products/pil/>`__ (PIL) or
   `Pillow <http://python-pillow.github.io/>`__;
-  `NumPy <http://www.numpy.org/>`__;
-  `pyglet <https://bitbucket.org/pyglet/pyglet>`__;
-  and `docopt <http://docopt.org/>`__.

Install Avena with `pip <https://pip.pypa.io/en/stable/>`__:

::

    pip install avena

Documentation
-------------

Documentation is available online at `Read the
Docs <http://avena.readthedocs.org/en/latest/>`__.

.. |image0| image:: https://travis-ci.org/eliteraspberries/avena.svg
   :target: https://travis-ci.org/eliteraspberries/avena
.. |image1| image:: https://codecov.io/github/eliteraspberries/avena/coverage.svg
   :target: https://codecov.io/github/eliteraspberries/avena
.. |image2| image:: https://img.shields.io/pypi/v/Avena.svg
   :target: https://pypi.python.org/pypi/Avena
.. |image3| image:: https://readthedocs.org/projects/avena/badge/?version=latest
   :target: http://avena.readthedocs.org/en/latest/
.. |image4| image:: https://img.shields.io/github/license/eliteraspberries/avena.svg
